@@ -30,6 +30,7 @@ using System;
 using Gtk;
 using Mono.Unix;
 
+using Hyena;
 using Hyena.Jobs;
 
 using Banshee.ServiceStack;
@@ -51,9 +52,9 @@ namespace Banshee.Gui.Dialogs
                 "Closing Banshee now will cancel any currently running tasks. They cannot " +
                 "be resumed automatically the next time Banshee is run.");
 
-            IconNameStock = Stock.DialogQuestion;
+            DialogIconNameStock = Stock.DialogQuestion;
 
-            Dialog.DefaultResponse = ResponseType.Cancel;
+            DefaultResponse = ResponseType.Cancel;
 
             AddButton(Catalog.GetString("Quit anyway"), ResponseType.Ok, false);
             AddButton(Catalog.GetString("Continue running"), ResponseType.Cancel, true);
@@ -75,7 +76,7 @@ namespace Banshee.Gui.Dialogs
         private void AddJob(Job job)
         {
             if (job.Has (PriorityHints.DataLossIfStopped)) {
-                Banshee.Base.ThreadAssist.ProxyToMain(delegate {
+                ThreadAssist.ProxyToMain(delegate {
                     TreeIter iter = (ListView.Model as ListStore).Prepend();
                     (ListView.Model as ListStore).SetValue(iter, 0, job.Title);
                     (ListView.Model as ListStore).SetValue(iter, 1, job);
@@ -86,7 +87,7 @@ namespace Banshee.Gui.Dialogs
         private void RemoveJob(Job job)
         {
             if(!scheduler.HasAnyDataLossJobs) {
-                Dialog.Respond(Gtk.ResponseType.Ok);
+                Respond(Gtk.ResponseType.Ok);
                 return;
             }
 
@@ -101,7 +102,7 @@ namespace Banshee.Gui.Dialogs
                 }
 
                 if(ListView.Model.GetValue(iter, 1) == job) {
-                    Banshee.Base.ThreadAssist.ProxyToMain(delegate {
+                    ThreadAssist.ProxyToMain(delegate {
                         (ListView.Model as ListStore).Remove(ref iter);
                     });
                     break;
